import React, { useRef, useEffect, useState } from 'react';
import { View, Text, StyleSheet, Animated, Image, PanResponder } from 'react-native';
import { rpx } from '../../utils/rpx'; // 根据需要调整路径

const Slider: React.FC = () => {
    const translateX = useRef(new Animated.Value(0)).current;
    const maxWidth = rpx(180); // 根据需要调整最大宽度
    const buttonWidth = rpx(86); // 按钮图片的宽度
    const [iconOpacity, setIconOpacity] = useState(1); // 初始透明度为1

    // 初始化 PanResponder
    const panResponder = useRef(
        PanResponder.create({
            onMoveShouldSetPanResponder: (_, gestureState) => {
                return Math.abs(gestureState.dx) > 20; // 调整灵敏度阈值
            },
            onPanResponderMove: (_, gestureState) => {
                const newTranslateX = Math.max(0, Math.min(maxWidth, translateX.__getValue() + gestureState.dx));
                translateX.setValue(newTranslateX); // 更新滑动值
            },
            onPanResponderRelease: (_, gestureState) => {
                let toValue = 0;

                // 判断滑动方向和滑动距离
                const threshold = maxWidth / 4; // 调整滑动阈值
                if (gestureState.dx > threshold) {
                    toValue = maxWidth; // 滑动超过阈值则解锁
                } else if (gestureState.dx < -threshold) {
                    toValue = 0; // 从右向左滑动超过阈值则返回
                } else {
                    toValue = translateX.__getValue() > threshold ? maxWidth : 0; // 否则根据当前位置判断
                }

                Animated.timing(translateX, {
                    toValue,
                    duration: 300,
                    useNativeDriver: false,
                }).start();
            },
        })
    ).current;

    // 计算背景色的宽度为当前滑动值加上按钮的宽度
    const backgroundColorWidth = translateX.interpolate({
        inputRange: [0, maxWidth],
        outputRange: [0, maxWidth + buttonWidth], // 背景色的宽度加上按钮的宽度
        extrapolate: 'clamp',
    });

    // 监听 translateX 的变化
    useEffect(() => {
        const listenerId = translateX.addListener(({ value }) => {
            // 根据 translateX 的值设置图标的透明度
            const newOpacity = value < maxWidth ? (1 - value / maxWidth) : 0; // 透明度随滑动而变化
            setIconOpacity(newOpacity); // 更新透明度
        });

        return () => {
            translateX.removeListener(listenerId); // 清理监听
        };
    }, [translateX]);

    return (
        <View style={styles.container}>
            <View style={styles.car_Opne_box}>
                {/* 已划过区域背景色 */}
                <Animated.View
                    style={[
                        styles.background,
                        {
                            width: backgroundColorWidth, // 使用计算的宽度
                            backgroundColor: '#4297F3', // 设置已滑动区域的背景色
                            zIndex: 1, // 确保背景在后面
                        }
                    ]}
                />
                {/* 默认背景色 */}
                <View style={[styles.defaultBackground]} />

                {/* 拖动按钮 */}
                <Animated.View
                    {...panResponder.panHandlers}
                    style={[
                        styles.imageContainer,
                        {
                            transform: [{
                                translateX // 使用 translateX 进行平移
                            }],
                            zIndex: 2, // 确保按钮在最上层
                        }
                    ]}
                >
                    <Image
                        source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uY9tYXXZztuE1VTLDl5y' }}
                        style={styles.imageContent}
                    />
                </Animated.View>

                {/* 最右边的图标 */}
                <Animated.Image
                    source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uEJob4XbADaL9ohOTVTL' }}
                    style={[
                        styles.icon,
                        { opacity: iconOpacity, zIndex: 2 } // 确保图标在按钮上面
                    ]}
                />
            </View>
            <Text style={styles.text}>右滑启动</Text>
        </View>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
    },
    car_Opne_box: {
        justifyContent: 'center',
        width: rpx(268),
        height: rpx(90),
        position: 'relative',
        borderRadius: rpx(45),
        overflow: 'hidden',
    },
    background: {
        height: '100%',
        borderRadius: rpx(45),
        position: 'absolute',
        left: 0,
        top: 0,
    },
    defaultBackground: {
        width: rpx(268),
        height: '100%',
        backgroundColor: '#EBEBEB', // 保持未滑动区域的默认颜色
        borderRadius: rpx(45),
    },
    imageContainer: {
        width: rpx(86), // 使用按钮的实际宽度
        height: rpx(86),
        position: 'absolute',
        top: '50%',
        left: 0,
        marginTop: -rpx(43),
        zIndex: 3, // 设置 zIndex，使其在最上层
    },
    imageContent: {
        width: '100%',
        height: '100%',
    },
    icon: {
        width: rpx(32),
        height: rpx(32),
        position: 'absolute',
        top: '50%',
        right: rpx(30),
        marginTop: -rpx(16),
        zIndex: 2, // 确保最右边的图标在最上面
    },
    text: {
        fontSize: rpx(32),
        color: '#3D3D3D',
        textAlign: 'center',
        marginTop: rpx(24),
    },
});

export default Slider;
